@@ -9,8 +9,8 @@
 ;; Created: Sep 18 2010
 ;; Keywords: languages, elisp, ruby
 ;; Package-Requires: ((emacs "25.1"))
-;; Package-Version: 20251001.2056
-;; Package-Revision: cec9ea862ef1
+;; Package-Version: 20260107.824
+;; Package-Revision: 1a3a93a6ba51
 
 ;; This file is not part of GNU Emacs.
 
@@ -886,12 +886,11 @@ not treated as modifications to the buffer."
              (string= erm-process-delimiter (substring erm-response -5 nil)))
     (setq response (substring erm-response 0 -5))
     (setq erm-response "")
-    (unless (buffer-live-p erm-parse-buff)
-      (erm-reset))
-    (when (buffer-live-p erm-parse-buff)
-      (with-current-buffer erm-parse-buff
-        (erm-with-unmodifying-text-property-changes
-         (erm-parse response))))))
+    (if (buffer-live-p erm-parse-buff)
+        (with-current-buffer erm-parse-buff
+          (erm-with-unmodifying-text-property-changes
+           (erm-parse response)))
+      (erm-reset))))
 
 (defun erm-ready ()
   (if erm-full-parse-p
@@ -1595,9 +1594,9 @@ With ARG, do it that many times."
             (if erm-full-parse-p
                 (enh-ruby-fontify-buffer)
               (let ((current (car erm-reparse-list)))
-                (if current
+                (when (and current (buffer-live-p current))
+                    (setq erm-reparse-list (cdr erm-reparse-list))
                     (with-current-buffer current
-                      (setq erm-reparse-list (cdr erm-reparse-list))
                       (enh-ruby-fontify-buffer))
                   (erm-do-syntax-check))))))
 
